from django.utils import timezone
import requests
from bs4 import BeautifulSoup
from django.conf import settings
from django.core.files.storage import FileSystemStorage


#Get ip address from request
def get_client_ip(request):
    x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR')
    if x_forwarded_for:
        ip = x_forwarded_for.split(',')[0]
    else:
        ip = request.META.get('REMOTE_ADDR')
    return ip

#create a variable date for autofills with extra days
def add_days(days=7):
    return timezone.now() + timezone.timedelta(days)

#Get game info from Ludopedia -chamado da admin action
    #O Nome do jog tem de match o nome no link para o jogo. Se nao, nao e encontrado
def buscar_informacoes(jogo):
    response=requests.get('https://ludopedia.com.br/jogo/'+jogo)
    html=response.text
    #deal with Jogo not found -> return is tested on the caller to make sure we have a game
    if 'Jogo não encontrado' in html:
        return 'error(naoencontrado)'
    soup=BeautifulSoup(html,'html.parser')
    info=soup.find_all("ul",attrs={'class':'list-inline'})[0]
    desc=soup.find_all('div',attrs={'class':'col-xs-12 col-sm-9'})[0]
    linha=[jogo,info('li')[0].text.replace('  ',' '),info('li')[1].text,info('li')[2].text,desc.text]
    return linha

#Handle File Upload and save it to a destination:
def handle_file_upload(file, path ):
    fs = FileSystemStorage(location=path)
    filename = fs.save(file.name, file)
    fileurl = fs.url(filename)
    return fileurl

#Le o csv e prepara o processo para realizar em grupos se passar do numero limite
def ler_csv(n,grupo):
    import os
    data=[]
    csv={}
    path = os.path.join('mediafiles', 'massimport')
    csv_files = [file for file in os.listdir(path) if file.lower().endswith('.csv')]
    with open(os.path.join(path,csv_files[0]),'r',encoding='utf-8') as file:
        first_line = file.readline().strip().lstrip('\ufeff')
        if ';' in first_line:
            delimiter=';'
        else:
            delimiter=','
        data.append(first_line.strip().split(delimiter))
        for line in file:
            row=line.strip().split(delimiter)
            data.append(row)
    for x,col in enumerate(data[0]):
        info=[]
        for linha in data[n+1:n+grupo+1]:
            info.append(linha[x])
        csv[col]=info
    return csv,n+grupo

 #retorna dados de logradouro de um CEP:
"""
 Sample reponse as a dict
  {
  "cep": "24230-191",
  "logradouro": "Rua Otávio Carneiro",
  "complemento": "lado par",
  "bairro": "Icaraí",
  "localidade": "Niterói",
  "uf": "RJ",
  "ibge": "3303302",
  "gia": "",
  "ddd": "21",
  "siafi": "5865"
}
"""
def get_address(cep):  
    url = "http://viacep.com.br/ws/"+cep+"/json/"
    response=requests.get(url)
    return response.json()

#Remove acentos do bairro, cidade para calculo de frete
def normalizar(texto: str):
    subs = [('á', 'a'), ('à', 'a'), ('â', 'a'), ('ã', 'a'), ('ä', 'a'), ('Á', 'a'), ('À', 'a'), ('Â', 'a'), ('Ã', 'a'), ('Ä', 'a'),
            ('é', 'e'), ('è', 'e'), ('ê', 'e'), ('ẽ', 'e'), ('ë', 'e'), ('É', 'e'), ('É', 'e'), ('Ê', 'e'), ('Ẽ', 'e'), ('Ë', 'e'),
            ('í', 'i'), ('ì', 'i'), ('î', 'i'), ('ĩ', 'i'), ('ï', 'i'), ('Í', 'i'), ('Í', 'i'), ('Î', 'i'), ('Ĩ', 'i'), ('Ï', 'i'),
            ('ó', 'o'), ('ò', 'o'), ('ô', 'o'), ('ô', 'o'), ('ö', 'o'), ('Ó', 'o'), ('Ò', 'o'), ('Ô', 'o'), ('Õ', 'o'), ('Ö', 'o'),
            ('ú', 'u'), ('ù', 'u'), ('û', 'u'), ('û', 'u'), ('ü', 'u'), ('Ú', 'u'), ('Ù', 'u'), ('Û', 'u'), ('Ũ', 'u'), ('Ü', 'u'),
            ('ç', 'c'), ('Ç', 'c'), 
            ('ñ', 'n'), ('Ñ', 'n'),
    ]
    for letra in subs:
        texto = texto.replace(letra[0], letra[1])
    texto = texto.lower()
    return(texto)